### 1、断言

用例结构如下：

主要介绍assert_content断言

```json
[
    {
        "caseLevel": "P1",
        "caseName": "购物车下单",
        "caseTier": "项目-首页-添加购物车-下单",
        "parametrize": [
            {"_title": "参数化数据1", "username": "A02441", "password":  "Xu173798"},
            {"_title": "参数化数据2", "username": "A02441", "password":  "xu1"}
        ],
        "caseNodes": [
            {
                "step_name": "登录飞熊平台",
                "driver": "api",
                "user": "user2",
                "param": {},
                "assert_content": [{"eq":["status_code", 200]}],  # √
            }
        ]
    }
]
```

```txt
"assert_content": [{"eq":["status_code", 200]}]
"assert_content": [{"断言类别":["提取返回结果表达式（接口返回结果）", 期望值]}]
```

### 2、断言类别：（兼容httprunner断言方法）

① 公用类别

```txt
"eq", "equals", "equal": 相等
"lt", "less_than"：小于
"le", "less_or_equals"：小于或等于
"gt", "greater_than"：大于
"ge", "greater_or_equals"：大于或等于
"ne", "not_equal"：不等于
"str_eq", "string_equals"：字符串相等
"len_eq", "length_equal"：长度相等
"len_gt", "length_greater_than"：长度大于
"len_ge", "length_greater_or_equals"： 长度大于等于
"len_lt", "length_less_than"：长度小于
"len_le","length_less_or_equals"：长度小于等于
"reg"：正则匹配匹配成功
"in", 实际结果在期望结果中
```

② UI 用例专用

```txt
ele_exits：元素存在
title_exits：浏览器title存在（支持模糊匹配："%title%"）同数据库like
```

### 3、断言返回结果提取表达式

语法同 extract 数据保存语法